plot.nlmixr2AugPred: Plot a nlmixr2 augPred object

View source: R/plot.nlmixr2AugPred.R

plot.nlmixr2AugPredR Documentation

Plot a nlmixr2 augPred object

Description

Plot a nlmixr2 augPred object

Usage

## S3 method for class 'nlmixr2AugPred'
plot(x, y, ..., log = "")

Arguments

x

augPred object

y

ignored, used to mach plot generic

...

Other arguments (ignored)

log

a character string which contains "x" if the x axis is to be logarithmic, "y" if the y axis is to be logarithmic and "xy" or "yx" if both axes are to be logarithmic (as in graphics::plot.default()). The default "" uses linear axes. Non-positive values cannot be shown on a log axis and are dropped.

Value

A ggtibble::gglist object (a list of ggplot2 objects, one per page of individual plots)

Examples



library(nlmixr2est)
## The basic model consiss of an ini block that has initial estimates
one.compartment <- function() {
  ini({
    tka <- 0.45 # Log Ka
    tcl <- 1 # Log Cl
    tv <- 3.45    # Log V
    eta.ka ~ 0.6
    eta.cl ~ 0.3
    eta.v ~ 0.1
    add.sd <- 0.7
  })
  # and a model block with the error sppecification and model specification
  model({
    ka <- exp(tka + eta.ka)
    cl <- exp(tcl + eta.cl)
    v <- exp(tv + eta.v)
    d/dt(depot) = -ka * depot
    d/dt(center) = ka * depot - cl / v * center
    cp = center / v
    cp ~ add(add.sd)
  })
}

## The fit is performed by the function nlmixr/nlmix2 specifying the model, data and estimate
fit <- nlmixr2est::nlmixr2(one.compartment, theo_sd,  est="saem",
                           saemControl(print=0, nBurn = 10, nEm = 20))

# augPred shows more points for the fit:

a <- nlmixr2est::augPred(fit)

# you can plot it with plot(augPred object)
plot(a)

# or with a log-scaled y axis
plot(a, log = "y")



nlmixr2plot documentation built on Sept. 23, 2026, 1:07 a.m.